@@ -51,13 +51,16 @@ def log_posterior_PMD(A, q, c, phi, x, k, N):
 
 
 class FrequentistPMD:
-    def __init__(self, data, sample, tax_id, method="posterior", p0=None):
+    def __init__(
+        self, data, sample, tax_id, method="posterior", p0=None, verbose=False
+    ):
         self.sample = sample
         self.tax_id = tax_id
         self.x = data["x"]
         self.k = data["k"]
         self.N = data["N"]
         self.method = method
+        self.verbose = verbose
         self._setup_p0(p0)
         self._setup_minuit()
         self.is_fitted = False
@@ -163,25 +166,48 @@ class FrequentistPMD:
         self.m.migrad()
         self.is_fitted = True
 
-        # first time try to reinitialise with previous fit result
+        # First try to refit it
         if not self.m.valid:
-            self.m.migrad()
+            if self.verbose:
+                print("refitting A")
+            for i in range(10):
+                self.m.migrad()
+                if self.m.valid:
+                    if self.verbose:
+                        print(f"Got out, A {i}")
+                    break
 
-        # if not working, continue with new guesses
+        # Then try with a totally flat guess
+        if not self.m.valid:
+            if self.verbose:
+                print("refitting B")
+            p0_flat = {"q": 0.0, "A": 0.0, "c": 0.01, "phi": 100}
+            self._setup_p0(p0_flat)
+            self.m.migrad()
+            if self.verbose:
+                print(f"Got out, B")
+
+        # If not working, continue with new guesses
+        MAX_GUESSES = 100
         if not self.m.valid:
             self.i = 0
+            if self.verbose:
+                print("refitting C")
             while True:
                 p0 = fit_utils.sample_from_param_grid(self.param_grid)
                 for key, val in p0.items():
                     self.m.values[key] = val
                 self.m.migrad()
-                if self.m.valid or self.i >= 100:
+                if self.m.valid or self.i >= MAX_GUESSES:
                     break
                 self.m.migrad()
-                if self.m.valid or self.i >= 100:
+                if self.m.valid or self.i >= MAX_GUESSES:
                     break
                 self.i += 1
 
+            if self.m.valid and self.verbose:
+                print(f"Got out, C {self.i}")
+
         self.valid = self.m.valid
 
         if self.valid:
@@ -263,14 +289,11 @@ class FrequentistPMD:
         c = self.c
         phi = self.phi
 
-        N = self.N[0]
+        N = max(self.N[0], 1)
 
         mu = A
 
-        if N != 0:
-            std = np.sqrt(A * (1 - A) * (phi + N) / ((phi + 1) * N))
-        else:
-            std = np.nan
+        std = np.sqrt(A * (1 - A) * (phi + N) / ((phi + 1) * N))
 
         return mu, std
 
@@ -623,7 +646,7 @@ def make_forward_reverse_fits(fit_result, data, sample, tax_id):
         fit_result[f"{var}"] = getattr(fit_all, var)
 
     numerator = fit_forward.D_max - fit_reverse.D_max
-    denominator = np.sqrt(fit_forward.D_max_std ** 2 + fit_reverse.D_max_std ** 2)
+    denominator = np.sqrt(fit_forward.D_max_std**2 + fit_reverse.D_max_std**2)
     fit_result["asymmetry"] = np.abs(numerator) / denominator
 
     for var in vars_to_keep:
